#multiSearch.py
############################################################################
#    External method EventFolder/Extensions/multiSearch.py
#    Ver 1.0  Aug 1 2000
#
#    License follows the Zope license, & use at your own risk
#    written and Copyright by Jeff Sasmor  (jeff@sasmor.com)
#
#############################################################################

import string

#############################################################################
#    xSearch does a catalog search using a 
#    list of dictionaries of variant parameters.
#    subjectFilter is a list of subjects to match against or IGNORE
#    if there's no filtering (usually this comes from a form SELECT list)
#    It also has a maximum # of return values, useful
#	 since the search results are kept in memory. A
#    useful value might be 50 to 100. 
#    the moderated param should be 'on' to filter out unreviewed items if 
#    the event log is moderated 
#    there should be an entry in each dict that is run:on or run:off to 
#    select whether or not to use that dict.  Useful to switch elements
#    of a search on or off from a form input (checkbox, for example)
#
#    This is not a GenPurp function, it is adapted to the needs of EventFolder's
#    eventReport method#
#
#    
##################################################################################

def xSearch(self, variant, subjectFilter, numResults, moderated):
	objList = []                        #empty result list
	for var in variant:
		argList = var               #ensure emptiness
		if argList['run'] <> 'on':	#skip this if the 'run' key isn't set to 'on'
			continue;
		else:
			del argList['run']	#don't want this sent to Catalog.searchResults

		results = self.Catalog.searchResults(argList)	#get results for this iteration.

		#scan thru results and add result OBJECTS (not the data_record_id_) to the object list
		for item in results:	#loop thru the results
			obj = self.Catalog.getobject(item.data_record_id_)	#get the object from the result item (an EventDoc)
			reviewedState = obj.reviewed	#have to do this here so that we get the actual reviewed state of THIS object,
							#rather than the reviewed state of its parent node IFF this an EvDocAdder
			flag = '0'  		

			if item.meta_type == 'EvDocAdder':	#this is a subobject, so get its parent!
				obj = obj.getParentNode()

			for thing in objList:	        	#if this EventDoc isn't already in the list
				if thing.id == obj.id:
					flag = '1'
					break
			if flag == '0':				#then this is an EventDoc that isn't in the list already
				subjMatch = 'no'
				if subjectFilter != 'IGNORE':		#if we're not ignoring subject categories
					for subj in subjectFilter:	#loop thru the candidate subject list
						if subj in obj.subject: #see if this subj is in the object's subject list
							subjMatch = 'yes' #if a match, flag it
							break;		#and we can stop looking
						
				if (subjectFilter == 'IGNORE') or (subjMatch == 'yes'): 
				#If we're ignoring subject categories or there has been a match--
				#now we have an EventDoc that's a new one, and it either matches the subject filter or the subject filter is IGNORE (don't filter)
				#so all that's left to do is to see if it we're checking for reviewed state				
					#If moderated == 'on' we have to chk the obj (the event doc) to see if it has the reviewed property == on
					if moderated == 'on':
						if reviewedState == 'on':
							objList.append(obj)		#if moderated and this was reviewed, add it
					else:  #if moderation is not used then we always append
						objList.append(obj)		#else always append it.
					
					
	return objList